package com.qianhe.system.controller;

import com.qianhe.common.annotation.Log;
import com.qianhe.common.core.controller.BaseController;
import com.qianhe.common.core.domain.AjaxResult;
import com.qianhe.common.core.page.TableDataInfo;
import com.qianhe.common.enums.BusinessType;
import com.qianhe.common.utils.poi.ExcelUtil;
import com.qianhe.system.domain.WaterOrder;
import com.qianhe.system.domain.WaterOrderGoods;
import com.qianhe.system.service.IWaterOrderGoodsService;
import com.qianhe.system.service.IWaterOrderService;
import com.qianhe.system.vo.WaterOrderVo;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.ArrayList;
import java.util.List;

/**
 * 订单Controller
 *
 * @author qianhe
 * @date 2023-11-23
 */
@RestController
@RequestMapping("/system/order")
public class WaterOrderController extends BaseController
{
    @Autowired
    private IWaterOrderService waterOrderService;
    @Autowired
    private IWaterOrderGoodsService waterOrderGoodsService;

    /**
     * 查询订单列表(管理端)
     */
    @GetMapping("/list")
    public TableDataInfo list(WaterOrderVo waterOrderVo)
    {
        startPage();
        List<WaterOrder> list = waterOrderService.selectWaterOrderList(waterOrderVo);
        //返回的订单列表
        List<WaterOrderVo> waterOrderVoList = new ArrayList<>();
        //查询所有订单商品
        List<WaterOrderGoods> waterOrderGoods = waterOrderGoodsService.selectWaterOrderGoodsList(new WaterOrderGoods());
        if (list.size() > 0){
            for (WaterOrder order : list) {
                //转vo
                WaterOrderVo waterOrderVo1 = new WaterOrderVo();
                BeanUtils.copyProperties(order,waterOrderVo1);
                List<WaterOrderGoods> waterOrderGoodsList = new ArrayList<>();
                for (WaterOrderGoods waterOrderGood : waterOrderGoods) {
                    if (order.getId().equals(waterOrderGood.getOrderId())){
//                        waterOrderGoodsList.add(waterOrderGood);
                        waterOrderVo1.setWaterOrderGoods(waterOrderGood);
                        waterOrderVoList.add(waterOrderVo1);
                    }
                }
//                if (waterOrderGoodsList.size() > 0){
//                    waterOrderVo1.setWaterOrderGoodsList(waterOrderGoodsList);
//                }
            }
        }
        TableDataInfo tableDataInfo = getDataTable(waterOrderVoList);
        tableDataInfo.setTotal(list.size());
        return tableDataInfo;
    }

    /**
     * 查询用户个人订单列表
     */
    @GetMapping("/listGr")
    public TableDataInfo listGr(WaterOrderVo waterOrderVo)
    {
        //返回的订单列表
        List<WaterOrderVo> waterOrderVoList = new ArrayList<>();
        List<WaterOrder> list = waterOrderService.selectWaterOrderList(waterOrderVo);
        //查询所有订单商品
        List<WaterOrderGoods> waterOrderGoods = waterOrderGoodsService.selectWaterOrderGoodsList(new WaterOrderGoods());
        if (list.size() > 0){
            for (WaterOrder order : list) {
                //转vo
                WaterOrderVo waterOrderVo1 = new WaterOrderVo();
                BeanUtils.copyProperties(order,waterOrderVo1);
                List<WaterOrderGoods> waterOrderGoodsList = new ArrayList<>();
                for (WaterOrderGoods waterOrderGood : waterOrderGoods) {
                    if (order.getId().equals(waterOrderGood.getOrderId())){
//                        waterOrderGoodsList.add(waterOrderGood);
                        waterOrderVo1.setWaterOrderGoods(waterOrderGood);
                        waterOrderVoList.add(waterOrderVo1);
                    }
                }
//                if (waterOrderGoodsList.size() > 0){
//                    waterOrderVo1.setWaterOrderGoodsList(waterOrderGoodsList);
//                }
                waterOrderVoList.add(waterOrderVo1);
            }
        }
        return getDataTable(waterOrderVoList);
    }

    /**
     * 导出订单列表
     */
    @Log(title = "订单", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WaterOrderVo waterOrderVo)
    {
        List<WaterOrder> list = waterOrderService.selectWaterOrderList(waterOrderVo);
        ExcelUtil<WaterOrder> util = new ExcelUtil<WaterOrder>(WaterOrder.class);
        util.exportExcel(response, list, "订单数据");
    }

    /**
     * 获取订单详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(waterOrderService.selectWaterOrderById(id));
    }

    /**
     * 新增订单
     */
    @Log(title = "订单", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WaterOrderVo waterOrderVo)
    {
        return toAjax(waterOrderService.insertWaterOrder(waterOrderVo));
    }

    /**
     * 修改订单
     */
    @Log(title = "订单", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WaterOrderVo waterOrderVo)
    {
        return toAjax(waterOrderService.updateWaterOrder(waterOrderVo));
    }

    /**
     * 删除订单
     */
    @Log(title = "订单", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(waterOrderService.deleteWaterOrderByIds(ids));
    }

    /**
     * 修改订单状态
     */
    @PostMapping("/updateOrderState")
    public AjaxResult updateOrderState(@RequestBody WaterOrderVo waterOrderVo){
        return toAjax(waterOrderService.updateOrderState(waterOrderVo));
    }
}
